kRecordColumn_RecordId = 0
kRecordColumn_Checked = 1
kRecordColumn_Tags = 2
kRecordColumn_CheckDate = 3
kRecordColumn_Date = 4
kRecordColumn_AccountTypeId = 5
kRecordColumn_AccountTypeName = 6
kRecordColumn_Description = 7
kRecordColumn_Txdate = 8
kRecordColumn_Amount = 9
kRecordColumn_InsertDate = 10
kRecordColumn_RawData = 11

kImportColumn_Status = 0
kImportColumn_Date = 1
kImportColumn_TxDate = 2
kImportColumn_Credit = 3
kImportColumn_Debit = 4
kImportColumn_Description = 5 

kDate_All = 0
kDate_PreviousYear = 1
kDate_PreviousMonth = 2
kdate_LastImport =3

kCheckedStatus_All =0
kCheckedStatus_Checked = 1
kCheckedStatus_UnChecked = 2

kInOutStatus_All = 0
kInOutStatus_In = 1
kInOutStatus_Out = 2

kTagCombo_All = 0
kTagCombo_With = 1
kTagCombo_Without = 2

kAccountTypeColumn_AccountTypeId = 0
kAccountTypeColumn_AccountName = 1
kAccountTypeColumn_DateField = 2
kAccountTypeColumn_DescriptionField = 3
kAccountTypeColumn_CreditField = 4
kAccountTypeColumn_DebitField = 5
kAccountTypeColumn_CurrencySign = 6
kAccountTypeColumn_DateFormat = 7

kTagsColumn_TagId = 0
kTagsColumn_TagName = 1
kTagsColumn_RecordIds = 2
kTagsColumn_Amount_in = 3
kTagsColumn_Amount_out = 4

kRecordTagsColumn_RecordTagId = 0
kRecordTagsColumn_RecordId = 1
kRecordTagsColumn_TagId = 2
