# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/pydosh.ui'
#
# Created: Sat Jun 22 12:53:39 2013
#      by: PyQt4 UI code generator 4.10
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_pydosh(object):
    def setupUi(self, pydosh):
        pydosh.setObjectName(_fromUtf8("pydosh"))
        pydosh.resize(1092, 745)
        self.widget_6 = QtGui.QWidget(pydosh)
        self.widget_6.setObjectName(_fromUtf8("widget_6"))
        self.gridLayout_4 = QtGui.QGridLayout(self.widget_6)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.widget_3 = QtGui.QWidget(self.widget_6)
        self.widget_3.setObjectName(_fromUtf8("widget_3"))
        self.gridLayout_3 = QtGui.QGridLayout(self.widget_3)
        self.gridLayout_3.setMargin(0)
        self.gridLayout_3.setObjectName(_fromUtf8("gridLayout_3"))
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem, 0, 3, 1, 1)
        self.groupBox_2 = QtGui.QGroupBox(self.widget_3)
        self.groupBox_2.setFlat(False)
        self.groupBox_2.setCheckable(False)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.gridLayout_5 = QtGui.QGridLayout(self.groupBox_2)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.label = QtGui.QLabel(self.groupBox_2)
        self.label.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout_5.addWidget(self.label, 0, 0, 1, 1)
        self.endDateEdit = QtGui.QDateEdit(self.groupBox_2)
        self.endDateEdit.setObjectName(_fromUtf8("endDateEdit"))
        self.gridLayout_5.addWidget(self.endDateEdit, 0, 1, 1, 2)
        self.label_2 = QtGui.QLabel(self.groupBox_2)
        self.label_2.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout_5.addWidget(self.label_2, 1, 0, 1, 1)
        self.startDateEdit = QtGui.QDateEdit(self.groupBox_2)
        self.startDateEdit.setObjectName(_fromUtf8("startDateEdit"))
        self.gridLayout_5.addWidget(self.startDateEdit, 1, 1, 1, 2)
        self.dateCombo = QtGui.QComboBox(self.groupBox_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dateCombo.sizePolicy().hasHeightForWidth())
        self.dateCombo.setSizePolicy(sizePolicy)
        self.dateCombo.setObjectName(_fromUtf8("dateCombo"))
        self.gridLayout_5.addWidget(self.dateCombo, 2, 1, 1, 2)
        self.gridLayout_3.addWidget(self.groupBox_2, 0, 0, 1, 1)
        self.groupBox = QtGui.QGroupBox(self.widget_3)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.gridLayout = QtGui.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label_14 = QtGui.QLabel(self.groupBox)
        self.label_14.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_14.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_14.setObjectName(_fromUtf8("label_14"))
        self.gridLayout.addWidget(self.label_14, 2, 2, 1, 1)
        self.label_6 = QtGui.QLabel(self.groupBox)
        self.label_6.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.gridLayout.addWidget(self.label_6, 3, 2, 1, 1)
        self.descEdit = SearchLineEdit(self.groupBox)
        self.descEdit.setObjectName(_fromUtf8("descEdit"))
        self.gridLayout.addWidget(self.descEdit, 2, 3, 1, 1)
        self.inoutCombo = QtGui.QComboBox(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.inoutCombo.sizePolicy().hasHeightForWidth())
        self.inoutCombo.setSizePolicy(sizePolicy)
        self.inoutCombo.setObjectName(_fromUtf8("inoutCombo"))
        self.gridLayout.addWidget(self.inoutCombo, 2, 1, 1, 1)
        self.label_13 = QtGui.QLabel(self.groupBox)
        self.label_13.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_13.setObjectName(_fromUtf8("label_13"))
        self.gridLayout.addWidget(self.label_13, 2, 0, 1, 1)
        self.accountCombo = MultiComboBox(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.accountCombo.sizePolicy().hasHeightForWidth())
        self.accountCombo.setSizePolicy(sizePolicy)
        self.accountCombo.setObjectName(_fromUtf8("accountCombo"))
        self.gridLayout.addWidget(self.accountCombo, 1, 3, 1, 1)
        self.label_4 = QtGui.QLabel(self.groupBox)
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.gridLayout.addWidget(self.label_4, 1, 2, 1, 1)
        self.label_15 = QtGui.QLabel(self.groupBox)
        self.label_15.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_15.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_15.setObjectName(_fromUtf8("label_15"))
        self.gridLayout.addWidget(self.label_15, 3, 0, 1, 1)
        self.tagsCombo = QtGui.QComboBox(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tagsCombo.sizePolicy().hasHeightForWidth())
        self.tagsCombo.setSizePolicy(sizePolicy)
        self.tagsCombo.setObjectName(_fromUtf8("tagsCombo"))
        self.gridLayout.addWidget(self.tagsCombo, 3, 1, 1, 1)
        self.checkedCombo = QtGui.QComboBox(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkedCombo.sizePolicy().hasHeightForWidth())
        self.checkedCombo.setSizePolicy(sizePolicy)
        self.checkedCombo.setObjectName(_fromUtf8("checkedCombo"))
        self.gridLayout.addWidget(self.checkedCombo, 1, 1, 1, 1)
        self.label_3 = QtGui.QLabel(self.groupBox)
        self.label_3.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.amountEdit = SearchLineEdit(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.amountEdit.sizePolicy().hasHeightForWidth())
        self.amountEdit.setSizePolicy(sizePolicy)
        self.amountEdit.setObjectName(_fromUtf8("amountEdit"))
        self.gridLayout.addWidget(self.amountEdit, 3, 3, 1, 1)
        self.gridLayout_3.addWidget(self.groupBox, 0, 2, 1, 1)
        self.gridLayout_4.addWidget(self.widget_3, 0, 0, 1, 1)
        self.widget_4 = QtGui.QWidget(self.widget_6)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_4.sizePolicy().hasHeightForWidth())
        self.widget_4.setSizePolicy(sizePolicy)
        self.widget_4.setObjectName(_fromUtf8("widget_4"))
        self.horizontalLayout_4 = QtGui.QHBoxLayout(self.widget_4)
        self.horizontalLayout_4.setMargin(0)
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.groupBox_4 = QtGui.QGroupBox(self.widget_4)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_4.sizePolicy().hasHeightForWidth())
        self.groupBox_4.setSizePolicy(sizePolicy)
        self.groupBox_4.setObjectName(_fromUtf8("groupBox_4"))
        self._2 = QtGui.QVBoxLayout(self.groupBox_4)
        self._2.setObjectName(_fromUtf8("_2"))
        self.widget = QtGui.QWidget(self.groupBox_4)
        self.widget.setObjectName(_fromUtf8("widget"))
        self._4 = QtGui.QHBoxLayout(self.widget)
        self._4.setContentsMargins(0, -1, 0, -1)
        self._4.setObjectName(_fromUtf8("_4"))
        self.toggleCheckButton = QtGui.QToolButton(self.widget)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/accept.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.toggleCheckButton.setIcon(icon)
        self.toggleCheckButton.setObjectName(_fromUtf8("toggleCheckButton"))
        self._4.addWidget(self.toggleCheckButton)
        self.reloadButton = QtGui.QToolButton(self.widget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/arrow_refresh.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.reloadButton.setIcon(icon1)
        self.reloadButton.setObjectName(_fromUtf8("reloadButton"))
        self._4.addWidget(self.reloadButton)
        self.deleteButton = QtGui.QToolButton(self.widget)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/cross.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.deleteButton.setIcon(icon2)
        self.deleteButton.setObjectName(_fromUtf8("deleteButton"))
        self._4.addWidget(self.deleteButton)
        spacerItem1 = QtGui.QSpacerItem(703, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self._4.addItem(spacerItem1)
        self.label_7 = QtGui.QLabel(self.widget)
        self.label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_7.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self._4.addWidget(self.label_7)
        self.scrolltoEdit = SearchLineEdit(self.widget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrolltoEdit.sizePolicy().hasHeightForWidth())
        self.scrolltoEdit.setSizePolicy(sizePolicy)
        self.scrolltoEdit.setObjectName(_fromUtf8("scrolltoEdit"))
        self._4.addWidget(self.scrolltoEdit)
        self._2.addWidget(self.widget)
        self.tableView = QtGui.QTableView(self.groupBox_4)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.MinimumExpanding, QtGui.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableView.sizePolicy().hasHeightForWidth())
        self.tableView.setSizePolicy(sizePolicy)
        self.tableView.setObjectName(_fromUtf8("tableView"))
        self._2.addWidget(self.tableView)
        self.widget_5 = QtGui.QWidget(self.groupBox_4)
        self.widget_5.setObjectName(_fromUtf8("widget_5"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout(self.widget_5)
        self.horizontalLayout_3.setMargin(0)
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.connectionStatusText = QtGui.QLabel(self.widget_5)
        self.connectionStatusText.setObjectName(_fromUtf8("connectionStatusText"))
        self.horizontalLayout_3.addWidget(self.connectionStatusText)
        spacerItem2 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.label_10 = QtGui.QLabel(self.widget_5)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.horizontalLayout_3.addWidget(self.label_10)
        self.inTotalLabel = QtGui.QLabel(self.widget_5)
        self.inTotalLabel.setLineWidth(-1)
        self.inTotalLabel.setObjectName(_fromUtf8("inTotalLabel"))
        self.horizontalLayout_3.addWidget(self.inTotalLabel)
        spacerItem3 = QtGui.QSpacerItem(28, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.label_11 = QtGui.QLabel(self.widget_5)
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.horizontalLayout_3.addWidget(self.label_11)
        self.outTotalLabel = QtGui.QLabel(self.widget_5)
        self.outTotalLabel.setObjectName(_fromUtf8("outTotalLabel"))
        self.horizontalLayout_3.addWidget(self.outTotalLabel)
        spacerItem4 = QtGui.QSpacerItem(134, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.label_12 = QtGui.QLabel(self.widget_5)
        self.label_12.setObjectName(_fromUtf8("label_12"))
        self.horizontalLayout_3.addWidget(self.label_12)
        self.recordCountLabel = QtGui.QLabel(self.widget_5)
        self.recordCountLabel.setObjectName(_fromUtf8("recordCountLabel"))
        self.horizontalLayout_3.addWidget(self.recordCountLabel)
        self._2.addWidget(self.widget_5)
        self.horizontalLayout_4.addWidget(self.groupBox_4)
        self.groupBox_3 = QtGui.QGroupBox(self.widget_4)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setObjectName(_fromUtf8("groupBox_3"))
        self._3 = QtGui.QVBoxLayout(self.groupBox_3)
        self._3.setObjectName(_fromUtf8("_3"))
        self.widget_2 = QtGui.QWidget(self.groupBox_3)
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.widget_2)
        self.horizontalLayout.setContentsMargins(0, -1, -1, -1)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.addTagButton = QtGui.QToolButton(self.widget_2)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/add.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.addTagButton.setIcon(icon3)
        self.addTagButton.setObjectName(_fromUtf8("addTagButton"))
        self.horizontalLayout.addWidget(self.addTagButton)
        self.removeTagButton = QtGui.QToolButton(self.widget_2)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/delete.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.removeTagButton.setIcon(icon4)
        self.removeTagButton.setObjectName(_fromUtf8("removeTagButton"))
        self.horizontalLayout.addWidget(self.removeTagButton)
        spacerItem5 = QtGui.QSpacerItem(60, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem5)
        self._3.addWidget(self.widget_2)
        self.tagView = TagTableView(self.groupBox_3)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tagView.sizePolicy().hasHeightForWidth())
        self.tagView.setSizePolicy(sizePolicy)
        self.tagView.setObjectName(_fromUtf8("tagView"))
        self._3.addWidget(self.tagView)
        self.horizontalLayout_4.addWidget(self.groupBox_3)
        self.gridLayout_4.addWidget(self.widget_4, 1, 0, 1, 1)
        pydosh.setCentralWidget(self.widget_6)
        self.label_14.setBuddy(self.descEdit)
        self.label_6.setBuddy(self.amountEdit)
        self.label_7.setBuddy(self.scrolltoEdit)

        self.retranslateUi(pydosh)
        QtCore.QMetaObject.connectSlotsByName(pydosh)

    def retranslateUi(self, pydosh):
        pydosh.setWindowTitle(_translate("pydosh", "pydosh", None))
        self.groupBox_2.setTitle(_translate("pydosh", "date", None))
        self.label.setText(_translate("pydosh", "end", None))
        self.endDateEdit.setToolTip(_translate("pydosh", "<html><head/><body><p>Set the end date filter</p></body></html>", None))
        self.label_2.setText(_translate("pydosh", "start", None))
        self.startDateEdit.setToolTip(_translate("pydosh", "<html><head/><body><p>Set the start date filter</p></body></html>", None))
        self.dateCombo.setToolTip(_translate("pydosh", "<html><head/><body><p>Select a date filter</p></body></html>", None))
        self.groupBox.setTitle(_translate("pydosh", "filter", None))
        self.label_14.setText(_translate("pydosh", "&description", None))
        self.label_6.setText(_translate("pydosh", "&amount", None))
        self.descEdit.setToolTip(_translate("pydosh", "<html><head/><body><p>filter on description (Alt-d)</p></body></html>", None))
        self.inoutCombo.setToolTip(_translate("pydosh", "<html><head/><body><p>filter on money in or out</p></body></html>", None))
        self.label_13.setText(_translate("pydosh", "in/out", None))
        self.accountCombo.setToolTip(_translate("pydosh", "<html><head/><body><p>filter on account type</p></body></html>", None))
        self.label_4.setText(_translate("pydosh", "account", None))
        self.label_15.setText(_translate("pydosh", "tags", None))
        self.tagsCombo.setToolTip(_translate("pydosh", "filter on checked status", None))
        self.checkedCombo.setToolTip(_translate("pydosh", "filter on checked status", None))
        self.label_3.setText(_translate("pydosh", "checked", None))
        self.amountEdit.setToolTip(_translate("pydosh", "<html><head/><body><p>filter by amount (Alt-a)</p><p>Accepts operators = &gt; &gt;= &lt; &lt;=</p></body></html>", None))
        self.groupBox_4.setTitle(_translate("pydosh", "Records", None))
        self.toggleCheckButton.setToolTip(_translate("pydosh", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Arial\'; font-size:10pt;\">toggle checked</span></p></body></html>", None))
        self.toggleCheckButton.setText(_translate("pydosh", "&t", None))
        self.reloadButton.setToolTip(_translate("pydosh", "reload data (Alt-r)", None))
        self.reloadButton.setText(_translate("pydosh", "&r", None))
        self.deleteButton.setToolTip(_translate("pydosh", "<html><head/><body><p>delete record(s)</p></body></html>", None))
        self.deleteButton.setText(_translate("pydosh", "&r", None))
        self.label_7.setText(_translate("pydosh", "&find", None))
        self.scrolltoEdit.setToolTip(_translate("pydosh", "<html><head/><body><p>find records matching description </p></body></html>", None))
        self.connectionStatusText.setText(_translate("pydosh", "TextLabel", None))
        self.label_10.setText(_translate("pydosh", "in:", None))
        self.inTotalLabel.setToolTip(_translate("pydosh", "total incoming for filtered records", None))
        self.inTotalLabel.setText(_translate("pydosh", "TextLabel", None))
        self.label_11.setText(_translate("pydosh", "out:", None))
        self.outTotalLabel.setToolTip(_translate("pydosh", "total outgoing for filtered records", None))
        self.outTotalLabel.setText(_translate("pydosh", "TextLabel", None))
        self.label_12.setText(_translate("pydosh", "showing:", None))
        self.recordCountLabel.setToolTip(_translate("pydosh", "filtered records / total records", None))
        self.recordCountLabel.setText(_translate("pydosh", "TextLabel", None))
        self.groupBox_3.setTitle(_translate("pydosh", "Tags", None))
        self.addTagButton.setText(_translate("pydosh", "...", None))
        self.removeTagButton.setText(_translate("pydosh", "...", None))

from searchlineedit import SearchLineEdit
from multicombobox import MultiComboBox
from views import TagTableView
import pydosh_rc
